# Remote Play 3DS

Remote play your modded 3DS.

This is one of demo applications of [Qingpi](https://github.com/U-1F992/qingpi), externally controlling system for the Nintendo 3DS.

```shell-session
> python -m remote_play_3ds $PORT $INDEX
```

![](screenshot.jpg)

## Setting

<dl>
<dt>

n3DS_view

</dt>
<dd>

- dot by dot x1
- no filter

</dd>
<dt>

OBS

</dt>
<dd>

- [OBS-VirtualCam](https://github.com/Avasam/obs-virtual-cam)
  - Built-in virtual camera behaves a bit buggy.
- Resize output (source size)
  - Output size will be width: 400px, height: 499px.
  - ja: 出力サイズ変更（ソースサイズ）

</dd>
<dl>